package com.goldenwater.slaj.eme.mapper;

import java.util.List;
import org.apache.ibatis.annotations.Mapper;
import com.goldenwater.slaj.eme.domain.BusiConplanBasic;

/**
 * 应急预案基本信息 数据层
 */
@Mapper
public interface BusiConplanBasicMapper {

    /**
     * 查询应急预案基本信息
     * @param guid 查询条件
     * @return 应急预案基本信息
     */
    BusiConplanBasic selectBusiConplanBasicByGuid(String guid);

    /**
     * 查询应急预案基本信息列表
     * @param busiConplanBasic 查询条件
     * @return 应急预案基本信息集合
     */
    List<BusiConplanBasic> selectBusiConplanBasicList(BusiConplanBasic busiConplanBasic);

    /**
     * 新增应急预案基本信息
     * @param busiConplanBasic 应急预案基本信息
     * @return 影响行数
     */
    int insertBusiConplanBasic(BusiConplanBasic busiConplanBasic);

    /**
     * 修改应急预案基本信息
     * @param busiConplanBasic 应急预案基本信息
     * @return 影响行数
     */
    int updateBusiConplanBasic(BusiConplanBasic busiConplanBasic);

    /**
     * 删除应急预案基本信息
     * @param guid 主键
     * @return 影响行数
     */
    int deleteBusiConplanBasicByGuid(String guid);

    /**
     * 批量删除应急预案基本信息
     * @param guids 主键数组
     * @return 影响行数
     */
    int deleteBusiConplanBasicByGuids(String[] guids);
}
